@@ -11,9 +11,11 @@
 #' @param bounds a vector specifying the wavelength range to analyze
 #' @param plot logical. Should plots indicating calculated parameters be returned? 
 #' (Defaults to \code{TRUE})
+#' @param ask logical, specifies whether user input needed to plot multiple plots
+#' when number of spectra to analyze is greater than 1 (defaults to \code{FALSE})
 #' @param ... additional arguments to be passed to plot
-#' @return a data frame containing peak height (max value), location (hue) and full width
-#' at half maximum, as well as half widths on left and right side of peak. Incl.min column
+#' @return a data frame containing column names (id); peak height (max value, B3), location (hue, H1) and full width
+#' at half maximum (FWHM), as well as half widths on left (HWHM.l) and right side of peak (HWHM.r). Incl.min column
 #' indicates whether user-defined bounds incorporate the actual minima of the spectra.
 #' Function will return a warning if not.
 #' @seealso \code{\link{procspec}}
@@ -27,10 +29,16 @@
 #' @author Chad Eliason \email{cme16@@zips.uakron.edu}, Rafael Maia \email{rm72@@zips.uakron.edu}
 
 peakshape <- function(rspecdata, select = NULL, bounds = c(300, 700), 
-                      plot = TRUE, ...) {
+                      plot = TRUE, ask = FALSE, ...) {
 
 old.par <- par(no.readonly = TRUE)  # all par settings that could be set
 
+par(ask = ask)
+
+# if (length(select) > 1)
+#   par(mfrow=c(2,2)) else
+#   par(mfrow=c(1,1))
+
 nms <- names(rspecdata)
 
 wl_index <- which(names(rspecdata)=='wl')
@@ -73,11 +81,12 @@ if (ncol(rspecdata)==1) {
   Yj <- apply(rspecdata2, 2, min)  # min refls
   Yk <- apply(rspecdata, 2, min)  # min refls, whole spectrum
   Xi <- sapply(1:ncol(rspecdata2), function(x) which(rspecdata2[, x]==Yi[x]))  # lambda_max index
-  fsthalf <- sapply(1:ncol(rspecdata2), function(x) rspecdata2[1:Xi[x], x])
-  sndhalf <- sapply(1:ncol(rspecdata2), function(x) rspecdata2[Xi[x]:nrow(rspecdata2), x])
+  fsthalf <- lapply(1:ncol(rspecdata2), function(x) rspecdata2[1:Xi[x], x])
+  sndhalf <- lapply(1:ncol(rspecdata2), function(x) rspecdata2[Xi[x]:nrow(rspecdata2), x])
   halfmax <- (Yi + Yj) / 2  # reflectance midpoint
   fstHM <- sapply(1:length(fsthalf), function(x) which.min(abs(fsthalf[[x]]-halfmax[x])))
-  sndHM <- sapply(1:length(fsthalf), function(x) which.min(abs(sndhalf[[x]]-halfmax[x])))
+  sndHM <- sapply(1:length(sndhalf), function(x) which.min(abs(sndhalf[[x]]-halfmax[x])))
+
 }
 
 
@@ -93,7 +102,7 @@ hue <- wlrange[Xi]
 if (plot==TRUE) {
   for (i in seq_along(select)) {
     plot(rspecdata[, i]~wl, type = 'l', xlab = "Wavelength (nm)", 
-         ylab = "Reflectance (%)", ...)
+         ylab = "Reflectance (%)", main = nms[select[i]], ...)
     abline(v = hue[i], col = "red")
     abline(h = halfmax[i], col = "red")
     abline(v = Xa[i], col = "red", lty = 2)
@@ -102,10 +111,13 @@ if (plot==TRUE) {
   }
 }
 
-out <- data.frame(B3 = as.numeric(Yi), H1 = hue, FWHM = Xb - Xa, HWHM.l = hue - Xa,
-                  HWHM.r = Xb - hue, incl.min = c("Yes", "No")[as.numeric(Yj>Yk)+1])
+out <- data.frame(id = nms[select], B3 = as.numeric(Yi), H1 = hue, 
+                  FWHM = Xb - Xa, HWHM.l = hue - Xa, HWHM.r = Xb - hue, 
+                  incl.min = c("Yes", "No")[as.numeric(Yj>Yk)+1])
 
-row.names(out) <- nms[select]
+# row.names(out) <- nms[select]
+
+par(old.par)
 
 out
 
